change log for gcc-testing (2010-05-27)

rtems-vc at rtems.org rtems-vc at rtems.org
Thu May 27 19:10:03 UTC 2010


 *jennifer*:
2010-05-27	Jennifer Averett <Jennifer.Averett at OARcorp.com>

	* ReportsBase.cc, ReportsBase.h, ReportsHtml.cc, ReportsHtml.h,
	ReportsText.cc, ReportsText.h: Added visual break between information
	sections in the annotated report.

M    1.9  covoar/ChangeLog
M    1.3  covoar/ReportsBase.h
M    1.4  covoar/ReportsBase.cc
M    1.2  covoar/ReportsHtml.h
M    1.3  covoar/ReportsHtml.cc
M    1.2  covoar/ReportsText.h
M    1.2  covoar/ReportsText.cc

diff -u gcc-testing/covoar/ChangeLog:1.8 gcc-testing/covoar/ChangeLog:1.9
--- gcc-testing/covoar/ChangeLog:1.8	Wed May 26 18:19:52 2010
+++ gcc-testing/covoar/ChangeLog	Thu May 27 13:11:29 2010
@@ -1,3 +1,9 @@
+2010-05-27	Jennifer Averett <Jennifer.Averett at OARcorp.com>
+
+	* ReportsBase.cc, ReportsBase.h, ReportsHtml.cc, ReportsHtml.h,
+	ReportsText.cc, ReportsText.h: Added visual break between information
+	sections in the annotated report.
+
 2010-05-26	Joel Sherrill <joel.sherrilL at OARcorp.com>
 
 	* CoverageReaderTSIM.cc: Branch coverage works now.

diff -u gcc-testing/covoar/ReportsBase.cc:1.3 gcc-testing/covoar/ReportsBase.cc:1.4
--- gcc-testing/covoar/ReportsBase.cc:1.3	Tue May 25 12:50:58 2010
+++ gcc-testing/covoar/ReportsBase.cc	Thu May 27 13:11:29 2010
@@ -201,6 +201,7 @@
     theBranches = ditr->second.uncoveredBranches;
 
     // Add annotations to each line where necessary
+    AnnotatedStart( aFile );
     for (itr = theInstructions->begin();
          itr != theInstructions->end();
          itr++ ) {
@@ -236,6 +237,8 @@
       
       PutAnnotatedLine( aFile, state, line, id); 
     }
+
+    AnnotatedEnd( aFile );
   }
 
   CloseAnnotatedFile( aFile );

diff -u gcc-testing/covoar/ReportsHtml.h:1.1 gcc-testing/covoar/ReportsHtml.h:1.2
--- gcc-testing/covoar/ReportsHtml.h:1.1	Mon May 24 15:07:08 2010
+++ gcc-testing/covoar/ReportsHtml.h	Thu May 27 13:11:29 2010
@@ -149,6 +149,16 @@
     );
 
     /* Inherit documentation from base class. */ 
+     virtual void AnnotatedStart(
+      FILE*                aFile
+    );
+ 
+    /* Inherit documentation from base class. */ 
+     virtual void AnnotatedEnd(
+      FILE*                aFile
+    );
+ 
+    /* Inherit documentation from base class. */ 
     virtual bool PutNoBranchInfo(
       FILE* report
     );

diff -u gcc-testing/covoar/ReportsHtml.cc:1.2 gcc-testing/covoar/ReportsHtml.cc:1.3
--- gcc-testing/covoar/ReportsHtml.cc:1.2	Tue May 25 12:50:58 2010
+++ gcc-testing/covoar/ReportsHtml.cc	Thu May 27 13:11:29 2010
@@ -406,6 +406,22 @@
     return aFile;
   }
 
+  void ReportsHtml::AnnotatedStart(
+    FILE*                aFile
+  )
+  {
+    fprintf( 
+      aFile,
+      "<hr>\n" 
+    );
+  }
+ 
+  void ReportsHtml::AnnotatedEnd(
+    FILE*                aFile
+  )
+  {
+  }
+
   void ReportsHtml::PutAnnotatedLine( 
     FILE*                aFile, 
     AnnotatedLineState_t state, 

diff -u gcc-testing/covoar/ReportsText.h:1.1 gcc-testing/covoar/ReportsText.h:1.2
--- gcc-testing/covoar/ReportsText.h:1.1	Mon May 24 15:07:08 2010
+++ gcc-testing/covoar/ReportsText.h	Thu May 27 13:11:30 2010
@@ -60,17 +60,30 @@
 
   protected:
 
+   /* Inherit documentation from base class. */ 
     virtual void PutAnnotatedLine( 
       FILE*                aFile, 
       AnnotatedLineState_t state, 
       std::string          line, 
       uint32_t             id 
     );
-
+ 
+   /* Inherit documentation from base class. */ 
+     virtual void AnnotatedStart(
+      FILE*                aFile
+    );
+ 
+    /* Inherit documentation from base class. */ 
+     virtual void AnnotatedEnd(
+      FILE*                aFile
+    );
+ 
+   /* Inherit documentation from base class. */ 
     virtual bool PutNoBranchInfo(
       FILE* report
     );
 
+   /* Inherit documentation from base class. */ 
     virtual bool PutBranchEntry(
       FILE*                                            report,
       unsigned int                                     number,
@@ -78,6 +91,7 @@
       Coverage::CoverageRanges::ranges_t::iterator     rangePtr
     );
 
+   /* Inherit documentation from base class. */ 
     virtual void putCoverageNoRange(
       FILE*        report,
       FILE*        noRangeFile,
@@ -85,6 +99,7 @@
       std::string  symbol
     );
 
+   /* Inherit documentation from base class. */ 
     virtual bool PutCoverageLine(
       FILE*                                           report,
       unsigned int                                    number,
@@ -92,6 +107,7 @@
       Coverage::CoverageRanges::ranges_t::iterator    ritr
     );
 
+   /* Inherit documentation from base class. */ 
     virtual bool PutSizeLine(
       FILE*                                           report,
       unsigned int                                    number,
@@ -99,12 +115,12 @@
       Coverage::CoverageRanges::ranges_t::iterator    range
     );
 
+   /* Inherit documentation from base class. */ 
     virtual bool PutSymbolSummaryLine(
       FILE*                                           report,
       unsigned int                                    number,
       Coverage::DesiredSymbols::symbolSet_t::iterator symbol
     );
-
 };
 
 }

diff -u gcc-testing/covoar/ReportsText.cc:1.1 gcc-testing/covoar/ReportsText.cc:1.2
--- gcc-testing/covoar/ReportsText.cc:1.1	Mon May 24 15:07:08 2010
+++ gcc-testing/covoar/ReportsText.cc	Thu May 27 13:11:30 2010
@@ -21,6 +21,23 @@
   reportExtension_m = ".txt";
 }
 
+void ReportsText::AnnotatedStart(
+  FILE*                aFile
+)
+{
+  fprintf( 
+    aFile, 
+    "========================================"
+    "=======================================\n" 
+  );
+}
+ 
+void ReportsText::AnnotatedEnd(
+  FILE*                aFile
+)
+{
+}
+
 void ReportsText::PutAnnotatedLine( 
   FILE*                aFile, 
   AnnotatedLineState_t state, 



diff -u gcc-testing/covoar/ReportsBase.h:1.2 gcc-testing/covoar/ReportsBase.h:1.3
--- gcc-testing/covoar/ReportsBase.h:1.2	Tue May 25 12:50:58 2010
+++ gcc-testing/covoar/ReportsBase.h	Thu May 27 13:11:29 2010
@@ -271,8 +271,8 @@
     );
 
     /*!
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
      *  @param[in] aFile identifies the report file name
      *  @param[in] state identifies the state machine state
@@ -287,6 +287,27 @@
     )=0;
 
     /*!
+     *  This method puts any necessary header information in
+     *  front of an annotated section.
+     *
+     *  @param[in] aFile identifies the report file name
+     */
+     virtual void AnnotatedStart(
+      FILE*                aFile
+    )=0;
+ 
+    /*!
+     *  This method puts any necessary footer information in
+     *  front of an annotated section.
+     *
+     *  @param[in] aFile identifies the report file name
+     */
+     virtual void AnnotatedEnd(
+      FILE*                aFile
+    )=0;
+ 
+
+    /*!
      *  This method puts any necessary footer information into
      *  the report then closes the file.
      *
@@ -271,8 +271,8 @@
 
     /*!
-     *  This method puts any necessary footer information into
-     *  the report then closes the file.
+     *  This method puts any necessary a line of annotated
+     *  data into the file.
      *
      *  @param[in] aFile identifies the report file name

--

Generated by Deluxe Loginfo [http://www.codewiz.org/projects/index.html#loginfo] 2.122 by Bernardo Innocenti <bernie at develer.com>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.rtems.org/pipermail/vc/attachments/20100527/10dbca10/attachment.html>


More information about the vc mailing list